pabulo_sdk library

Classes

AbstractBaseModel<M>
Abstract class to be extended by all model objects to provide compatibility with generics operations.
AbstractEvent
Abstract Event class to define the basis of the event.
AbstractLogin
Abstract Interface class implemented by all the repositories to provide easy access to check if the SDK has the current JWT Token or need to issue a login or show the login screen.
AbstractResponseModel<M>
Abstract Response Model is used as the bases to handle the backend response. Backend will always send response in the following JSON format:
AbstractValidator
A validator is the implementation similar to JAVA Hibernate validation features.
AccountBookEntryDto
Account book entry is the core object that holds the wallet balance.
AccountTxHistoryDto
Account transaction history
AddressDto
Address data model
AdminRoleDto
Admin Role object that is returned as part of the direct call to WhoAmI or through the consumer admin roles.
AllergyDto
Allergy object is used to store a list of allergies for a given consumer.
ApiFormPartDto
This object is used for preparing the multi-part data upload used by the RestRequestHandler.httpAuthUpload handler.
ApiKeyDto
The API Object Model.
AppLocalizations
Callers can lookup localized strings with an instance of AppLocalizations returned by AppLocalizations.of(context).
AppLocalizationsEn
The translations for English (en).
ApproveFacilityDto
This object is part of the Request to approve the facility.
ApproveReviewDto
BackEndValue
Abstract interface to be implemented by object to get backend values.
BusinessHourDto
Business Hours Object
CareItemDto
CarePackDto
ConsFramework
Constants defined for the overall SDK framework
ConsLogging
Logging Constants
ConsumerAttributesDto
This object is returned by the end-point UriConsumer.uriInformation
ConsumerExtraDto
This object is returned in two ways, either directly calling the RepoConsumer end points or through the RepoOperations end-point as part of facility approvals.
ConsumerFacilityLinkDto
This is a view (list) only to see the consumers that are linked to many facilities.
ConsumerLinkFacilityDto
ConsumerPayRequestDto
This dto is to get the information about the pay request, requester and recipient details.
ConsumerSignUpDto
After a successful sign up (create account) the backend will return the unique ID and the email back for the front-end in order to keep it as part of the profile management on the UI side.
DecCareConfirmDto
Decoded Object for QR Code Care Confirm.
DecCatalogItemDto
Loyalty Catalog Item
DecConsumerDto
QR Decoded Consumer Object
DecFacilityDto
Decoded Object for Facility
DecFacilityPayMe
Decode Object for Facility PayMe. Author: Adhvent Adhish
DecFundRaiserDto
Decoded Object for Fundraiser
DonatedItemDto
Item that was part of the donation.
DonationDto
Donation Data returned by the backend.
DonationItemDto
Donation Item returned from the backend.
DonationPickUpItemDto
EmergencyContactDto
Emergency Contacts for a given consumer.
FacilitiesConsumerDto
Data Object that is passed from the backend that contains:
FacilityConfigDto
Facility Configuration DTO stores the configuration information about the facility.
FacilityCrudDto
Create and Update a facility.
FacilityDto
This is a facility DTO that is returned by the backend as part of the list of facilities.
FacilityFeedConfigDto
Each facility have a feed type configured with the maximum days that feed can be created.
FacilityFeedDto
This is the compact view of the feeds for a facility. These objects are used by front end to show the list of feeds i.e., EVENT, etc.
FacilityReviewDto
Facility Review
FacilityVectorDto
Facility Vector Data Object is returned by the backend after completing a MongoDb Atlas Vector Search based on the facility about description.
FeedDto
This is the main object that is returned for all interaction with the different types of Feeds, or workflows from the backend.
FeedForApprovalDto
FeedRsvpdDto
Data object for the feed that this consumer had RSVP'd.
FeedSavedDto
This data object is used to fetch the information about the feed that was saved by the consumer as part of the save feed. Author: Adhvent Adhish
FrameWorkUtils
Framework utilities defined as static for developer support.
GoogleFcmKeyDto
Fire Base cloud messaging project setup.
HumanDto
Consumer Attributes are human attributes for a given consumer.
ImageCfgDto
The image configuration from the backend.
ImageDto
General Purpose Image Object
InBoxMessageDto
JsonDateTimeConverter
Custom Handler for date time conversions.
JwtRefreshSuccessEvent
These are events that are triggered throughout the SDK framework.
KbArticleDto
Knowledge base object is returned by the backend.
LocationDto
Latitude ~ Longitude Object
LoginDto
This is the object that is returned after a successful login to the backend.
LoginRequiredEvent
This event is triggered with JWT Token is not setup, or the call to RepoAdmin.letMeIn was unsuccessful.
LoyaltyCareDto
Loyalty Care Rule data object.
LoyaltyCatalogItemDto
Loyalty Catalog Item.
LoyaltyCreateDto
LoyaltyExpirationDto
LoyaltyFeedDto
Loyalty Feed's are the points rule that is executed once a user scan or interacts with this specific feedType.
LoyaltyPointTxDto
Loyalty Point Transaction details.
LoyaltyProgramDto
Loyalty Program Object.
LoyaltyReferralDto
LoyaltyReviewDto
Loyalty Review Points
LoyaltyRewardTierDto
LoyaltySpendDto
LoyaltyStatsDto
Loyalty Statistics of the current user.
LoyaltyVisitDto
MaxWithdrawDto
Object for holding the maximum amount allowed to withdraw with the charges.
MembershipDto
Facility Memberships that is created by a facility.
MoneyDto
Money class is used as the standard object to hold amounts.
NameAddressDto
This is a general purpose object that is used as a holder for common data items within a mongoDb projection operations.
OpenCloseDto
OrganizationDto
PabuloGlobals
This class must be instant before the start of the application.
PasswordPolicyDto
PayerPayeeDto
Payer / Payee are the sides of the transaction that identifies who paid for what service.
RateDto
Rates are like rate-table where a facility can publish standard rates for example: Birthday Parties etc.
RecipeItemCrudDto
Recipe Item used as part of the CRUD operations.
RecipeItemDto
Recipe Item DTO is returned as part of the standard response object from the backend.
RepGenFeed
These end-points are related to feed operations, mostly agnostic to a facility or a consumer.
RepoAdmin
Administration or Admin is misleading due to the fact that the backend started as part of the internal usage system.
RepoCarePack
Care Package related operations.
RepoConfigurations
Configuration end-points used for fetching backend configurations.
RepoConLoyalty
Consumer Loyalty End-Points.
RepoConsumer
Consumer REST APIs
RepoConWallet
Consumer Wallet REST AP's
RepoFacility
Facility Management
RepoFtyFeed
Feed's are workflows within the platform, these are associated with a specific facility.
RepoFtyWallet
Facility wallet operations.
RepoHerAi
AI end-points
RepoIntegration
3rd party integration end-points to provide extensions to the platform.
RepoLoyalty
Loyalty end-points used for platform administrations.
RepoMembership
Manage subscription's for a facility and customer.
RepoOperations
Business Operations end-points used for platform administrations.
RepoQrHandler
QR Code Handler
RepoUtility
Utilities end-point for developers and front-end integrate
ReqAdminAccess
Request to add administrator roles.
ReqAllergies
ReqApiKey
Request Object to create a new API Key.
ReqApproveFacility
Approve facility request is used to send the approval settings to the back end API.
ReqApproveReviews
ReqCarePackage
Request to create the care package.
ReqCareReserve
Reserve Care Pack
ReqCashDonate
Request to donation cash to a charity.
ReqCashTopUp
This request is used for two types of operations:
ReqCashWithdrawal
Request for cash withdrawal.
ReqConDebitTx
Request to debit a consumer wallet using the 3rd party integration end-points.
ReqConFacility
Request for Owner Email of the facility.
ReqConPayRequests
Request to send ask or pay request to friends.
ReqConsumerInfo
ReqConsumerSignUp
Create the Login for a user.
ReqEmergencyContacts
ReqFacilityCollectQrCode
Request used for creating the collections QR Code for a given facility.
ReqFacilityCrud
Request to create & update facility.
ReqFacilityDebitTx
Request to debit a facility wallet using the 3rd party integration end-points.
ReqFacilityFeed
Request to create a facility feed.
ReqFinanceTx
Request Object for Debit or Credit consumer or facility wallet.
ReqKbArticle
Request Object to create Knowledge base articles.
ReqLogin
Send the user credentials to the backend to login.
ReqLoyaltyCatalog
Loyalty Catalog items are redemptions items that are presented to the users as part of Points to Item redemptions.
ReqLoyaltyProgram
Request to create loyalty program.
ReqMemShipOffer
Membership offer item.
ReqPasswordChange
Change the current password.
ReqPointsTx
Operations process to Debit or Credit Points on a Primary loyalty program only.
ReqPushNotify
ReqRate
Request to create a rate item for a given facility
ReqRecipe
Request to create a recipe item for a facility.
ReqReferral
Refer a friend.
ReqReview
Create a review for a facility
ReqScannedQrCode
This request is used for the entire platform where there is a need to scan the platform generated QR Codes.
ReqSepaQr
SEPA is a European payment system. These are the inputs required to generate a SEPA compliant QR code.
RestRequestHandler
This is the core HTTP handler for the backend operations.
ReviewForApprovalDto
Get the facility review for approval.
RoleDto
Role is the individual part of the Admin Roles A role can be FACILITY_APPROVE, FACILITY_REVIEW, FEED_APPROVE FINANCE etc.
RspAllergies
Get the allergies for the consumer.
RspApiException
PoJo returned as standard error for all HTTP Exceptions
RspApiKey
Response Object to get API Keys from the backend.
RspCarePackage
Response object for Care Package
RspCfgFeedDays
Get the Feed Types configured for the facility
RspCfgGoogleFcm
RspCfgImage
RspCfgIntValue
Response Object where the backend will return only int as data.
RspCfgMemFee
Fees that are charged to purchase a membership.
RspCfgMoney
Configuration for match fees.
RspCfgPasswordPolicy
Get the password policy
RspCfgTopUpFee
This is a list of Facilities that are linked to a consumer.
RspConPayRequests
Consumer Pay Request's
RspConsumerExInfo
Get the consumer information and extra data items like email validated, admin roles etc.
RspConsumerInfo
RspConsumerSignUp
This is the response that is generated from the backend as part of creating a new user.
RspDonationItem
Response Object returned
RspDonationPickup
RspDonations
List of Donations
RspEmergencyContacts
Emergency Contacts for this consumer.
RspFacilitiesOfConsumer
Read Facilities by using consumer email.
RspFacilityCrud
This response is sent back from the server indicating what are the fields that were updated / created.
RspFacilityFeed
Response for updating the feed.
RspFacilityFeeds
List of facility feeds for display in the front end as a list item.
RspFacilityReviews
Facility Reviews
RspFacilityVectors
Facility vectors are search results done by the backend using the MongoDb Atlas Vector Search.
RspFeedRsvp
This response is to get the RSVP of this feed.
RspFeeds
Response for reading feeds of different types.
RspFeedsBooked
This response is for the list of feeds the consumer has RSVP'd or booked and optionally paid.
RspFeedsForApproval
Response object for approving feeds.
RspFeedsSaved
Response for list of feeds that are saved by this consumer
RspImage
This is the response that is returned by the backend when images are successfully uploaded to the backend.
RspInBoxMessages
RspJwtRefresh
JWT Token refreshed is send as a string that needs to be cached and added to the subsequent calls.
RspKbArticles
Response object that is returned by the backend.
RspLinkFacility
Link Facility Data Model
RspLogin
Response object returned after successful login.
RspLoyaltyAttribs
This object is returned after the Create Loyalty Program is posted.
RspLoyaltyPrgs
Loyalty Program This item is returned as a list even if it is a Primary Program Or the same item is returned as a list for Facility loyalty program.
RspLoyaltyStats
RspLtyCatalogItems
Response for Loyalty Catalog Items.
RspMapValues
This is a general purpose response model that is used in places where the backend will send a Map<String, String> values.
RspMaxCashWithdraw
The maximum cash withdrawal.
RspMemShipOffers
List of Facility specific membership items.
RspNoData
There are API's that do not need to reply with a data object.
RspQrB64String
The backend sends the image a Base 64 encoded string for the image.
RspQrDecode
QR Code Decoder for responding to various QR Code data.
RspRates
Response to get Rates for a given facility.
RspRecipe
Response to get the single recipe for a facility.
RspRecipes
List of recipes.
RspReviewForApproval
Approve Facility reviews
RspStringValues
This is a general purpose response model that is used in places where the backend will send a list of Strings in a array.
RspSubscriptions
List of subscriptions the user has bought from facilities.
RspSysStatus
System Status response
RspVewFacilities
List of Facilities or Charities.
RspVewFacility
View a single facility
RspWalletBalances
Wallet Balances for consumer or facility.
RspWalletHistory
Wallet Transaction History
RspWhoAmi
Returns the Administrator roles assigned to this user.
RsvpDto
SentimentDto
SubscriptionDto
Read Only Subscription that is bought by a consumer from a facility View.
SysStatusDto
TopUpFeeDto
UriAdmin
URI's for the Admin End-Point.
UriCarePack
Care Management End-Points.
UriConfiguration
Configuration end-points.
UriConLoyalty
Consumer Loyalty URI
UriConsumer
Consumer End-Points
UriConWallet
Consumer Wallet / Cash Transaction URI.
UriDto
UriExternal
URI's to use for connecting with external integrations only.
UriFacilities
UriFacility
Facility End-Points
UriFeed
General Feed
UriFeeds
UriFtyFeeds
Facility Feeds URIs.
UriFtyLoyalty
URI for Facility Loyalty
UriFtyRecipe
Facility Recipe URI's
UriFtyWallet
UriHer
This class is inspired by the film Her where the operating system gets so personal that it actually learns to be jealous of a physical human.
UriIntegration
3rd party end-point for extending the platform.
UriIntFinance
URI's for Financial Integration.
UriLoyalty
Loyalty end-points
UriMembership
Membership end-points.
UriOperations
Uri Operations that defines the UriV1Root.baseUrl plus /ops
UriOpsConsumer
Operations on Consumer
UriOpsFacility
Facility Operations. The root is UriOperations._rootBaseUri/fty.
UriOpsFeed
Feed or Feeds management.
UriOpsFinance
Operations on Wallets / Finance / Stripe etc.
UriOpsGeneral
General Operations End-Points.
UriOpsLoyalty
UriQRCode
Master qr scanner that is used to get all the QR Code's and manage the logic around it.
UriUtility
Utility End-Points
UriV1Root
URI Root class is used to setup the base URI from the AppConfig.

Enums

AccessRole
Enum that defines the Role Types
FeedType
Feed Type are the standard workflows that are implemented in the backend.
QrCodeType
This enum is used for creating the QR Code.
StatusType
General Status returned by the backend.

Extensions

$AccountBookEntryDtoCopyWith on AccountBookEntryDto
$AccountTxHistoryDtoCopyWith on AccountTxHistoryDto
$AddressDtoCopyWith on AddressDto
$AdminRoleDtoCopyWith on AdminRoleDto
$AllergyDtoCopyWith on AllergyDto
$ApiKeyDtoCopyWith on ApiKeyDto
$ApproveFacilityDtoCopyWith on ApproveFacilityDto
$ApproveReviewDtoCopyWith on ApproveReviewDto
$BusinessHourDtoCopyWith on BusinessHourDto
$CareItemDtoCopyWith on CareItemDto
$CarePackDtoCopyWith on CarePackDto
$ConsumerAttributesDtoCopyWith on ConsumerAttributesDto
$ConsumerExtraDtoCopyWith on ConsumerExtraDto
$ConsumerFacilityLinkDtoCopyWith on ConsumerFacilityLinkDto
$ConsumerLinkFacilityDtoCopyWith on ConsumerLinkFacilityDto
$ConsumerPayRequestDtoCopyWith on ConsumerPayRequestDto
$ConsumerSignUpDtoCopyWith on ConsumerSignUpDto
$DecCareConfirmDtoCopyWith on DecCareConfirmDto
$DecCatalogItemDtoCopyWith on DecCatalogItemDto
$DecConsumerDtoCopyWith on DecConsumerDto
$DecFacilityDtoCopyWith on DecFacilityDto
$DecFacilityPayMeCopyWith on DecFacilityPayMe
$DecFundRaiserDtoCopyWith on DecFundRaiserDto
$DonatedItemDtoCopyWith on DonatedItemDto
$DonationDtoCopyWith on DonationDto
$DonationItemDtoCopyWith on DonationItemDto
$DonationPickUpItemDtoCopyWith on DonationPickUpItemDto
$EmergencyContactDtoCopyWith on EmergencyContactDto
$FacilitiesConsumerDtoCopyWith on FacilitiesConsumerDto
$FacilityConfigDtoCopyWith on FacilityConfigDto
$FacilityCrudDtoCopyWith on FacilityCrudDto
$FacilityDtoCopyWith on FacilityDto
$FacilityFeedConfigDtoCopyWith on FacilityFeedConfigDto
$FacilityFeedDtoCopyWith on FacilityFeedDto
$FacilityReviewDtoCopyWith on FacilityReviewDto
$FacilityVectorDtoCopyWith on FacilityVectorDto
$FeedDtoCopyWith on FeedDto
$FeedForApprovalDtoCopyWith on FeedForApprovalDto
$FeedRsvpdDtoCopyWith on FeedRsvpdDto
$FeedSavedDtoCopyWith on FeedSavedDto
$GoogleFcmKeyDtoCopyWith on GoogleFcmKeyDto
$HumanDtoCopyWith on HumanDto
$ImageCfgDtoCopyWith on ImageCfgDto
$ImageDtoCopyWith on ImageDto
$InBoxMessageDtoCopyWith on InBoxMessageDto
$KbArticleDtoCopyWith on KbArticleDto
$LocationDtoCopyWith on LocationDto
$LoginDtoCopyWith on LoginDto
$LoyaltyCareDtoCopyWith on LoyaltyCareDto
$LoyaltyCatalogItemDtoCopyWith on LoyaltyCatalogItemDto
$LoyaltyCreateDtoCopyWith on LoyaltyCreateDto
$LoyaltyExpirationDtoCopyWith on LoyaltyExpirationDto
$LoyaltyFeedDtoCopyWith on LoyaltyFeedDto
$LoyaltyPointTxDtoCopyWith on LoyaltyPointTxDto
$LoyaltyProgramDtoCopyWith on LoyaltyProgramDto
$LoyaltyReferralDtoCopyWith on LoyaltyReferralDto
$LoyaltyReviewDtoCopyWith on LoyaltyReviewDto
$LoyaltyRewardTierDtoCopyWith on LoyaltyRewardTierDto
$LoyaltySpendDtoCopyWith on LoyaltySpendDto
$LoyaltyStatsDtoCopyWith on LoyaltyStatsDto
$LoyaltyVisitDtoCopyWith on LoyaltyVisitDto
$MaxWithdrawDtoCopyWith on MaxWithdrawDto
$MembershipDtoCopyWith on MembershipDto
$MoneyDtoCopyWith on MoneyDto
$NameAddressDtoCopyWith on NameAddressDto
$OpenCloseDtoCopyWith on OpenCloseDto
$OrganizationDtoCopyWith on OrganizationDto
$PasswordPolicyDtoCopyWith on PasswordPolicyDto
$PayerPayeeDtoCopyWith on PayerPayeeDto
$RateDtoCopyWith on RateDto
$RecipeItemCrudDtoCopyWith on RecipeItemCrudDto
$RecipeItemDtoCopyWith on RecipeItemDto
$ReviewForApprovalDtoCopyWith on ReviewForApprovalDto
$RoleDtoCopyWith on RoleDto
$RsvpDtoCopyWith on RsvpDto
$SentimentDtoCopyWith on SentimentDto
$SubscriptionDtoCopyWith on SubscriptionDto
$SysStatusDtoCopyWith on SysStatusDto
$TopUpFeeDtoCopyWith on TopUpFeeDto
$UriDtoCopyWith on UriDto

Exceptions / Errors

ApiException
API Exception is thrown when the backend returns any Response.statusCode == 4xx.